==> rustc_1.70.0+dfsg1.orig.tar.xz: rustc-1.70.0-src/tests/rustdoc-js/generics.js <==
// exact-check

const QUERY = [
    'R<P>',
    'R<struct:P>',
    'R<enum:P>',
    '"P"',
    'P',
    'ExtraCreditStructMulti<ExtraCreditInnerMulti, ExtraCreditInnerMulti>',
    'TraitCat',
    'TraitDog',
    'Result<String>',
];

const EXPECTED = [
    {
        // R<P>
        'returned': [
            { 'path': 'generics', 'name': 'alef' },
        ],
        'in_args': [
            { 'path': 'generics', 'name': 'alpha' },
        ],
    },
    {
        // R<struct:P>
        'returned': [
            { 'path': 'generics', 'name': 'alef' },
        ],
        'in_args': [
            { 'path': 'generics', 'name': 'alpha' },
        ],
    },
    {
        // R<enum:P>
        'returned': [],
        'in_args': [],
    },
    {
        // "P"
        'others': [
            { 'path': 'generics', 'name': 'P' },
        ],
        'returned': [
            { 'path': 'generics', 'name': 'alef' },
        ],
        'in_args': [
            { 'path': 'generics', 'name': 'alpha' },
        ],
    },
    {
        // P
        'returned': [
            { 'path': 'generics', 'name': 'alef' },
        ],
        'in_args': [
            { 'path': 'generics', 'name': 'alpha' },
        ],
    },
    {
        // "ExtraCreditStructMulti"<ExtraCreditInnerMulti, ExtraCreditInnerMulti>
        'in_args': [
            { 'path': 'generics', 'name': 'extracreditlabhomework' },
        ],
        'returned': [],
    },
    {
        // TraitCat
        'in_args': [
            { 'path': 'generics', 'name': 'gamma' },
        ],
    },
    {
        // TraitDog
        'in_args': [
            { 'path': 'generics', 'name': 'gamma' },
        ],
    },
    {
        // Result<String>
        'others': [],
        'returned': [
            { 'path': 'generics', 'name': 'super_soup' },
        ],
        'in_args': [
            { 'path': 'generics', 'name': 'super_soup' },
        ],
    },
];

==> rustc_1.91.1+dfsg1.orig.tar.xz: rustc-1.91.1-src/tests/rustdoc-js/generics.js <==
// exact-check
// ignore-order

const EXPECTED = [
    {
        'query': 'R<P>',
        'returned': [
            { 'path': 'generics', 'name': 'alef' },
        ],
        'in_args': [
            { 'path': 'generics', 'name': 'alpha' },
        ],
    },
    {
        'query': 'R<struct:P>',
        'returned': [
            { 'path': 'generics', 'name': 'alef' },
        ],
        'in_args': [
            { 'path': 'generics', 'name': 'alpha' },
        ],
    },
    {
        'query': 'R<enum:P>',
        'returned': [],
        'in_args': [],
    },
    {
        'query': '"P"',
        'others': [
            { 'path': 'generics', 'name': 'P' },
        ],
        'returned': [],
        'in_args': [],
    },
    {
        'query': 'P',
        'returned': [],
        'in_args': [],
    },
    {
        'query': '"ExtraCreditStructMulti"<ExtraCreditInnerMulti, ExtraCreditInnerMulti>',
        'in_args': [
            { 'path': 'generics', 'name': 'extracreditlabhomework' },
        ],
        'returned': [],
    },
    {
        'query': 'TraitCat',
        'in_args': [
            { 'path': 'generics', 'name': 'gamma' },
        ],
    },
    {
        'query': 'TraitDog',
        'in_args': [
            { 'path': 'generics', 'name': 'gamma' },
        ],
    },
    {
        'query': 'Result<String>',
        'others': [],
        'returned': [
            { 'path': 'generics', 'name': 'super_soup' },
        ],
        'in_args': [
            { 'path': 'generics', 'name': 'super_soup' },
        ],
    },
];
